@@ -6,6 +6,7 @@ import pendulum
 from .blog import Blog, BlogPost
 from .feeds import RSSFeedEngine, RSSFeedItem
 
+
 class MicroBlogPost(BlogPost):
     """
     Page Like Object with slight modifications to work with BlogPosts
@@ -21,12 +22,11 @@ class MicroBlogPost(BlogPost):
             the content in an rss format
     """
 
-
     def __init__(self, **kwargs):
         """checks published options and accepts the first that is listed"""
         super().__init__(**kwargs)
 
-        self.slug = pendulum.parse(self.date_published, strict=False).format("YMMDDHHmmss")
+        self.slug = self.date_published.format("YMMDDHHmmss")
         self.title = ""
 
 
